@@ -94,7 +94,12 @@ class PaymentData(BaseModel):
     notice_code: Union[str, None]
     iud: str
     iuv: Union[str, None]
-    split: Union[Dict[str, Optional[float]], List[Optional[PaymentDataSplit]], None]
+    split: Union[
+        Dict[str, Optional[float]],
+        List[Dict[str, Union[float, str, None]]],
+        List[Optional[PaymentDataSplit]],
+        None,
+    ]
 
     class Config:
         validate_all = True
@@ -103,9 +108,14 @@ class PaymentData(BaseModel):
     paid_at_must_be_iso8601 = validator('paid_at', allow_reuse=True)(check_isoformat_none_case)
     expire_at_must_be_iso8601 = validator('expire_at', allow_reuse=True)(check_iso_format)
 
-    def split_append(self, split):
-        for item in split:
-            self.split.append(PaymentDataSplit(**item))
+    def set_split(self, split):
+        if isinstance(split, List):  # lo split è una lista di voci di bilancio
+            try:
+                self.split = [PaymentDataSplit(**item) for item in split]
+            except (ValidationError, TypeError):
+                self.split = split
+        elif isinstance(split, Dict) or not split:  # lo split cpntiene l'importo di ogni voce di bilancio o un None
+            self.split = split
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
