@@ -31,6 +31,7 @@ from ._helpers import (
     get_payment_event_data,
     get_split_data,
     get_split_data_v2,
+    get_split_data_v2_complete,
     get_update_data,
 )
 
@@ -126,9 +127,19 @@ class PaymentTestCase(TestCase):
 
     def test_encoders(self):
         payment = Payment(**get_payment_event_data())
+
         payment_data_v2 = payment.payment
-        payment_data_v2.split = get_split_data_v2()
+        payment_data_v2.set_split(get_split_data_v2())
         payment_v2 = Payment(**get_payment_event_data(payment=payment_data_v2))
+
+        payment_data_v2_complete = payment.payment
+        payment_data_v2_complete.set_split(get_split_data_v2_complete())
+        payment_v2_complete = Payment(**get_payment_event_data(payment=payment_data_v2_complete))
+
+        payment_data_v2_empty = payment.payment
+        payment_data_v2_empty.set_split(None)
+        payment_v2_empty_split = Payment(**get_payment_event_data(payment=payment_data_v2_empty))
+
         payment_data = PaymentData(**get_payment_data())
         split = PaymentDataSplit(**get_split_data())
         online_payment_begin = OnlinePaymentBegin(**get_online_payment_begin_data())
@@ -139,6 +150,30 @@ class PaymentTestCase(TestCase):
 
         self.assertEqual(json.loads(payment.json())['id'], 'bb7044e4-066c-4bf7-915e-87ee97270eae')
         self.assertEqual(json.loads(payment_v2.json())['payment']['split'], {'c_1': 14.0, 'c_2': None})
+        self.assertEqual(
+            json.loads(payment_v2_complete.json())['payment']['split'],
+            [
+                {
+                    'id': 'c_1',
+                    'tipo': 'Tipo c1',
+                    'codice': 'Codice c1',
+                    'descrizione': 'Descrizione c1',
+                    'importo': 16.0,
+                    'capitolo_bilancio': 'Capitolo di bilancio c1',
+                    'accertamento': 'Accertamento c1',
+                },
+                {
+                    'id': 'c_2',
+                    'tipo': 'Tipo c2',
+                    'codice': 'Codice c2',
+                    'descrizione': 'Descrizione c12',
+                    'importo': 0.5,
+                    'capitolo_bilancio': 'Capitolo di bilancio c2',
+                    'accertamento': 'Accertamento c2',
+                },
+            ],
+        )
+        self.assertEqual(json.loads(payment_v2_empty_split.json())['payment']['split'], None)
         self.assertEqual(json.loads(payment.json())['created_at'], '2022-06-08T08:28:42+00:00')
         self.assertEqual(json.loads(payment.status.json()), PaymentStatus.STATUS_CREATION_PENDING.value)
         self.assertEqual(json.loads(payment.type.json()), PaymentType.TYPE_PAGOPA.value)
